Package {StatisticTeach1}


Type: Package
Title: Interactive Tool for Statistics and Probability Teaching
Version: 0.1.0
Description: A 'shiny' application designed to support the learning of basic concepts in statistics and probability. Provides an interactive interface that allows students to explore and visualize descriptive statistics, frequency tables, and probability distributions intuitively.
License: GPL-3
Imports: descriptr, DescTools, dplyr, ggplot2, magrittr, mixdist, RColorBrewer, readxl, rlang, shiny, shinyBS, shinydashboard, shinyjs, shinyWidgets, tibble, tidyr, colourpicker
Suggests: knitr, rmarkdown, testthat (≥ 3.0.0)
VignetteBuilder: knitr
Encoding: UTF-8
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-26 23:05:32 UTC; jdelahoz
Author: Javier De La Hoz Maestre ORCID iD [cre, aut], Humberto Llinas Solano ORCID iD [aut]
Maintainer: Javier De La Hoz Maestre <jdelahoz@unimagdalena.edu.co>
Repository: CRAN
Date/Publication: 2026-05-30 08:20:02 UTC

Frequency table for categorical data Frequency table for categorical data.

Description

Frequency table for categorical data Frequency table for categorical data.

Usage

ST_freq_factor(data, variable)

Arguments

data

A data.frame or a tibble.

variable

Column (factor) in data.

Value

A data.frame with frequency, cumulative frequency, frequency percent and cumulative frequency percent.

Examples

ST_freq_factor(iris,Species)

Frequency table for continuous data Frequency table for continuous data.

Description

Frequency table for continuous data Frequency table for continuous data.

Usage

ST_freq_numeric(data, variable, bins = 5)

Arguments

data

A data.frame or a tibble.

variable

Column in data.

bins

Number of intervals into which the data must be split.

Value

A data.frame with frequency, cumulative frequency, frequency percent and cumulative frequency percent.

Examples

ST_freq_numeric(mtcars, mpg,bins = 5)

Shiny GUI for StatisticTeach1 package

Description

runStatisticTeach1() loads interactive user interface built using R 'shiny'.

Usage

runStatisticTeach1(host = "127.0.0.1", port = NULL, launch.browser = TRUE)

Arguments

host

The IPv4 address that the application should listen on. Defaults to the shiny.host option, if set, or "127.0.0.1" if not.

port

is the TCP port that the application should listen on. If the port is not specified, and the shiny.port option is set (with options(shiny.port = XX)), then that port will be used. Otherwise, use a random port.

launch.browser

If true, the system's default web browser will be launched automatically after the app is started. Defaults to true in interactive sessions only. This value of this parameter can also be a function to call with the application's URL.

Details

The interactive user interface to provide an easy way for to perform descriptive statistical analysis

Value

No return value

Examples

if(interactive()){
runStatisticTeach1()
}